@@ -21,7 +21,7 @@ def check_type(item, item_type):
     """
     if not isinstance(item, item_type):
         if item:
-            logger.warn("item {} is not of type {} so skipping".format(item, item_type.__name__))
+            logger.warning("item {} is not of type {} so skipping".format(item, item_type.__name__))
         return item_type()
     return item
 
@@ -32,7 +32,7 @@ def cast_number_or_zero(item):
         return decimal.Decimal(item)
     except (ValueError, TypeError):
         if item:
-            logger.warn("item {} is not a number treating as zero".format(item))
+            logger.warning("item {} is not a number treating as zero".format(item))
         return 0
 
 
@@ -46,7 +46,7 @@ def cast_string(item):
         return str(item)
 
     if item:
-        logger.warn("item {} is not able to be converted to a string".format(item))
+        logger.warning("item {} is not able to be converted to a string".format(item))
     return ""
 
 
@@ -85,14 +85,16 @@ def _run_transforms(releases, project_id=None, records=None, output=None, transf
 
 
 class InitialTransformState:
-    def __init__(self, releases, project_id=None, records=None, output=None):
+    def __init__(self, releases_or_release_packages, project_id=None, records=None, output=None):
 
+        # coerce generator into list as we iterate over it twice.
+        releases_or_release_packages = list(releases_or_release_packages)
         all_releases = []
-        for release in releases:
-            if is_package(release):
-                all_releases.extend(check_type(release.get("releases"), list))
+        for releases_or_release_package in releases_or_release_packages:
+            if is_package(releases_or_release_package):
+                all_releases.extend(check_type(releases_or_release_package.get("releases"), list))
             else:
-                all_releases.append(release)
+                all_releases.append(releases_or_release_package)
 
         self.releases = sorted_releases(all_releases)
         self.releases_by_ocid = defaultdict(list)
@@ -105,7 +107,7 @@ class InitialTransformState:
         records = records
 
         if not records:
-            record_package = next(merge(releases, return_package=True, use_linked_releases=True))
+            record_package = next(merge(releases_or_release_packages, return_package=True, use_linked_releases=True))
             records = check_type(record_package.get("records"), list)
 
         compiled_releases = []
@@ -681,7 +683,7 @@ def description(state):
         description = resolve_pointer(compiled_release, "/planning/project/description", None)
         if description:
             if output_description and output_description != description:
-                logger.warn(
+                logger.warning(
                     "Multiple differing planning/project/descriptions found eg. {}, {}, skipping conversion".format(
                         description, output_description
                     )
