@@ -3,7 +3,7 @@ from tempfile import TemporaryFile
 
 import pytest
 
-from ocdskit.util import is_record, json_dump
+from ocdskit.util import is_linked_release, is_record, json_dump
 from tests import read
 
 
@@ -22,6 +22,16 @@ def test_is_record(filename, expected):
     assert is_record(json.loads(read(filename))) == expected
 
 
+@pytest.mark.parametrize('data,expected', [
+    ({'url': 'http://example.com'}, True),
+    ({'url': 'http://example.com', 'date': '2001-02-03T04:05:06Z'}, True),
+    ({'url': 'http://example.com', 'date': '2001-02-03T04:05:06Z', 'tag': ['tender']}, True),
+    ({'url': 'http://example.com', 'date': '2001-02-03T04:05:06Z', 'tag': ['tender'], 'id': '1'}, False),
+])
+def test_is_linked_release(data, expected):
+    assert is_linked_release(data) == expected
+
+
 @pytest.mark.parametrize('data,expected', [
     (iter([]), '[]'),
     ({'a': 1, 'b': 2}, '{"a":1,"b":2}'),
